/**
 * (C) Copyright IBM Corp. 2021.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/// <reference types="node" />
import { IncomingHttpHeaders, OutgoingHttpHeaders } from 'http';
import { BaseService, UserOptions } from 'ibm-cloud-sdk-core';
/**
 * No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)
 *
 * API Version: 1.0
 */
declare class EventNotificationsV1 extends BaseService {
    static DEFAULT_SERVICE_URL: string;
    static DEFAULT_SERVICE_NAME: string;
    /*************************
     * Factory method
     ************************/
    /**
     * Constructs an instance of EventNotificationsV1 with passed in options and external configuration.
     *
     * @param {UserOptions} [options] - The parameters to send to the service.
     * @param {string} [options.serviceName] - The name of the service to configure
     * @param {Authenticator} [options.authenticator] - The Authenticator object used to authenticate requests to the service
     * @param {string} [options.serviceUrl] - The URL for the service
     * @returns {EventNotificationsV1}
     */
    static newInstance(options: UserOptions): EventNotificationsV1;
    /**
     * Construct a EventNotificationsV1 object.
     *
     * @param {Object} options - Options for the service.
     * @param {string} [options.serviceUrl] - The base url to use when contacting the service. The base url may differ between IBM Cloud regions.
     * @param {OutgoingHttpHeaders} [options.headers] - Default headers that shall be included with every request to the service.
     * @param {Authenticator} options.authenticator - The Authenticator object used to authenticate requests to the service
     * @constructor
     * @returns {EventNotificationsV1}
     */
    constructor(options: UserOptions);
    /*************************
     * sources
     ************************/
    /**
     * List all Sources.
     *
     * List all Sources.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceList>>}
     */
    listSources(params: EventNotificationsV1.ListSourcesParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SourceList>>;
    /**
     * Get a Source.
     *
     * Get a Sources.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Source.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>}
     */
    getSource(params: EventNotificationsV1.GetSourceParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Source>>;
    /*************************
     * topics
     ************************/
    /**
     * Create a new Topic.
     *
     * Create a new Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Name of the topic.
     * @param {string} [params.description] - Description of the topic.
     * @param {TopicUpdateSourcesItem[]} [params.sources] - List of sources.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicResponse>>}
     */
    createTopic(params: EventNotificationsV1.CreateTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicResponse>>;
    /**
     * List all Topics.
     *
     * List all Topics.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicList>>}
     */
    listTopics(params: EventNotificationsV1.ListTopicsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.TopicList>>;
    /**
     * Get details of a Topic.
     *
     * Get details of a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {string} [params.include] - Include sub topics.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>}
     */
    getTopic(params: EventNotificationsV1.GetTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>;
    /**
     * Update details of a Topic.
     *
     * Update details of a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {string} [params.name] - Name of the topic.
     * @param {string} [params.description] - Description of the topic.
     * @param {TopicUpdateSourcesItem[]} [params.sources] - List of sources.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>}
     */
    replaceTopic(params: EventNotificationsV1.ReplaceTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Topic>>;
    /**
     * Delete a Topic.
     *
     * Delete a Topic.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Topic.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteTopic(params: EventNotificationsV1.DeleteTopicParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * destinations
     ************************/
    /**
     * Create a new Destination.
     *
     * Create a new Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - The Destintion name.
     * @param {string} params.type - The type of Destination Webhook.
     * @param {string} [params.description] - The Destination description.
     * @param {DestinationConfig} [params.config] - Payload describing a destination configuration.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationResponse>>}
     */
    createDestination(params: EventNotificationsV1.CreateDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationResponse>>;
    /**
     * List all Destinations.
     *
     * List all Destinations.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationList>>}
     */
    listDestinations(params: EventNotificationsV1.ListDestinationsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.DestinationList>>;
    /**
     * Get details of a Destination.
     *
     * Get details of a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>}
     */
    getDestination(params: EventNotificationsV1.GetDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>;
    /**
     * Update details of a Destination.
     *
     * Update details of a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {string} [params.name] - Destination name.
     * @param {string} [params.description] - Destination description.
     * @param {DestinationConfig} [params.config] - Payload describing a destination configuration.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>}
     */
    updateDestination(params: EventNotificationsV1.UpdateDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Destination>>;
    /**
     * Delete a Destination.
     *
     * Delete a Destination.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Destination.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteDestination(params: EventNotificationsV1.DeleteDestinationParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /*************************
     * subscriptions
     ************************/
    /**
     * Create a new Subscription.
     *
     * Create a new Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.name - Subscription name.
     * @param {string} params.destinationId - Destination ID.
     * @param {string} params.topicId - Topic ID.
     * @param {SubscriptionCreateAttributes} params.attributes -
     * @param {string} [params.description] - Subscription description.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    createSubscription(params: EventNotificationsV1.CreateSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /**
     * List all Subscriptions.
     *
     * List all Subscriptions.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {number} [params.offset] - offset for paginated results.
     * @param {number} [params.limit] - Page limit for paginated results.
     * @param {string} [params.search] - Search string for filtering results.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.SubscriptionList>>}
     */
    listSubscriptions(params: EventNotificationsV1.ListSubscriptionsParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.SubscriptionList>>;
    /**
     * Get details of a Subscription.
     *
     * Get details of a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    getSubscription(params: EventNotificationsV1.GetSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
    /**
     * Delete a Subscription.
     *
     * Delete a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>}
     */
    deleteSubscription(params: EventNotificationsV1.DeleteSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Empty>>;
    /**
     * Update details of a Subscription.
     *
     * Update details of a Subscription.
     *
     * @param {Object} params - The parameters to send to the service.
     * @param {string} params.instanceId - Unique identifier for IBM Cloud Event Notifications instance.
     * @param {string} params.id - Unique identifier for Subscription.
     * @param {string} [params.name] - Name of the subscription.
     * @param {string} [params.description] - Description of the subscription.
     * @param {SubscriptionUpdateAttributes} [params.attributes] -
     * @param {OutgoingHttpHeaders} [params.headers] - Custom request headers
     * @returns {Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>}
     */
    updateSubscription(params: EventNotificationsV1.UpdateSubscriptionParams): Promise<EventNotificationsV1.Response<EventNotificationsV1.Subscription>>;
}
/*************************
 * interfaces
 ************************/
declare namespace EventNotificationsV1 {
    /** An operation response. */
    interface Response<T = any> {
        result: T;
        status: number;
        statusText: string;
        headers: IncomingHttpHeaders;
    }
    /** The callback for a service request. */
    type Callback<T> = (error: any, response?: Response<T>) => void;
    /** The body of a service request that returns no response data. */
    interface Empty {
    }
    /** A standard JS object, defined to avoid the limitations of `Object` and `object` */
    interface JsonObject {
        [key: string]: any;
    }
    /*************************
     * request interfaces
     ************************/
    /** Parameters for the `listSources` operation. */
    interface ListSourcesParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getSource` operation. */
    interface GetSourceParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Source. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createTopic` operation. */
    interface CreateTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description?: string;
        /** List of sources. */
        sources?: TopicUpdateSourcesItem[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listTopics` operation. */
    interface ListTopicsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getTopic` operation. */
    interface GetTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        /** Include sub topics. */
        include?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `replaceTopic` operation. */
    interface ReplaceTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        /** Name of the topic. */
        name?: string;
        /** Description of the topic. */
        description?: string;
        /** List of sources. */
        sources?: TopicUpdateSourcesItem[];
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteTopic` operation. */
    interface DeleteTopicParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Topic. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createDestination` operation. */
    interface CreateDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** The Destintion name. */
        name: string;
        /** The type of Destination Webhook. */
        type: CreateDestinationConstants.Type | string;
        /** The Destination description. */
        description?: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        headers?: OutgoingHttpHeaders;
    }
    /** Constants for the `createDestination` operation. */
    namespace CreateDestinationConstants {
        /** The type of Destination Webhook. */
        enum Type {
            WEBHOOK = "webhook"
        }
    }
    /** Parameters for the `listDestinations` operation. */
    interface ListDestinationsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Page limit for paginated results. */
        limit?: number;
        /** offset for paginated results. */
        offset?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getDestination` operation. */
    interface GetDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateDestination` operation. */
    interface UpdateDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        /** Destination name. */
        name?: string;
        /** Destination description. */
        description?: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteDestination` operation. */
    interface DeleteDestinationParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Destination. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `createSubscription` operation. */
    interface CreateSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Subscription name. */
        name: string;
        /** Destination ID. */
        destinationId: string;
        /** Topic ID. */
        topicId: string;
        attributes: SubscriptionCreateAttributes;
        /** Subscription description. */
        description?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `listSubscriptions` operation. */
    interface ListSubscriptionsParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** offset for paginated results. */
        offset?: number;
        /** Page limit for paginated results. */
        limit?: number;
        /** Search string for filtering results. */
        search?: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `getSubscription` operation. */
    interface GetSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `deleteSubscription` operation. */
    interface DeleteSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        headers?: OutgoingHttpHeaders;
    }
    /** Parameters for the `updateSubscription` operation. */
    interface UpdateSubscriptionParams {
        /** Unique identifier for IBM Cloud Event Notifications instance. */
        instanceId: string;
        /** Unique identifier for Subscription. */
        id: string;
        /** Name of the subscription. */
        name?: string;
        /** Description of the subscription. */
        description?: string;
        attributes?: SubscriptionUpdateAttributes;
        headers?: OutgoingHttpHeaders;
    }
    /*************************
     * model interfaces
     ************************/
    /** Payload describing a destination get request. */
    interface Destination {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook. */
        type: string;
        /** Payload describing a destination configuration. */
        config?: DestinationConfig;
        /** Last updated time. */
        updated_at: string;
        /** Number of subscriptions. */
        subscription_count: number;
        /** List of subscriptions. */
        subscription_names: string[];
    }
    /** Payload describing a destination configuration. */
    interface DestinationConfig {
        params: DestinationConfigParams;
    }
    /** DestinationConfigParams. */
    interface DestinationConfigParams {
    }
    /** Destination object. */
    interface DestinationLisItem {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook. */
        type: string;
        /** Subscription count. */
        subscription_count: number;
        /** Names of subscriptions. */
        subscription_names: string[];
        /** Updated at. */
        updated_at: string;
    }
    /** Payload describing a destination list request. */
    interface DestinationList {
        /** Total number of destinations. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show destinations. */
        limit: number;
        /** List of destinations. */
        destinations: DestinationLisItem[];
    }
    /** Payload describing a destination get request. */
    interface DestinationResponse {
        /** Destination ID. */
        id: string;
        /** Destination name. */
        name: string;
        /** Destination description. */
        description: string;
        /** Destination type Email/SMS/Webhook. */
        type: string;
        /** Payload describing a destination configuration. */
        config: DestinationConfig;
        /** Last updated time. */
        created_at: string;
    }
    /** Rule object. */
    interface Rules {
        /** Whether the rule is enabled or not. */
        enabled?: boolean;
        /** Event type filter. */
        event_type_filter: string;
        /** Notification filter. */
        notification_filter?: string;
    }
    /** Rule object. */
    interface RulesGet {
        /** Whether the rule is enabled or not. */
        enabled: boolean;
        /** Event type filter. */
        event_type_filter: string;
        /** Notification filter. */
        notification_filter: string;
        /** Last time the topic was updated. */
        updated_at: string;
        /** Autogenerated rule ID. */
        id: string;
    }
    /** Payload describing a source generate request. */
    interface Source {
        /** The id of the source. */
        id: string;
        /** The name of the source. */
        name: string;
        /** The description of the source. */
        description: string;
        /** The status of the source. */
        enabled: boolean;
        /** Type of the source. */
        type: string;
        /** The last updated time of the source. */
        updated_at: string;
        /** The number of topics. */
        topic_count: number;
        /** The names of the topics. */
        topic_names: string[];
    }
    /** Payload describing a source list request. */
    interface SourceList {
        /** Number of sources. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show sources. */
        limit: number;
        /** List of sources. */
        sources: SourcesListItem[];
    }
    /** Payload describing a source list item. */
    interface SourcesListItem {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** Description of the source. */
        description: string;
        /** Type of the source. */
        type: string;
        /** Whether the source is enabled or not. */
        enabled: boolean;
        /** Time of the last update. */
        updated_at: string;
        /** Number of topics. */
        topic_count: number;
    }
    /** Subscription object. */
    interface Subscription {
        /** Subscription ID. */
        id: string;
        /** Subscription name. */
        name: string;
        /** Subscription description. */
        description: string;
        /** Last updated time. */
        updated_at: string;
        /** From Email ID (it will be displayed only in case of smtp_ibm destination type). */
        from?: string;
        /** The type of destination. */
        destination_type: string;
        /** The destination ID. */
        destination_id: string;
        /** The destination name. */
        destination_name: string;
        /** Topic ID. */
        topic_id: string;
        /** Topic name. */
        topic_name: string;
        attributes: SubscriptionAttributes;
        /** Subscription accepts additional properties. */
        [propName: string]: any;
    }
    /** SubscriptionAttributes. */
    interface SubscriptionAttributes {
    }
    /** SubscriptionCreateAttributes. */
    interface SubscriptionCreateAttributes {
    }
    /** Subscription list object. */
    interface SubscriptionList {
        /** Number of subscriptions. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show subscriptions. */
        limit: number;
        /** List of subscriptions. */
        subscriptions: SubscriptionListItem[];
    }
    /** Subscription list item. */
    interface SubscriptionListItem {
        /** ID of the subscription. */
        id: string;
        /** Name of the subscription. */
        name: string;
        /** Description of the subscription. */
        description: string;
        /** ID of the destination. */
        destination_id: string;
        /** Name of the destination. */
        destination_name?: string;
        /** The type of destination. */
        destination_type: string;
        /** ID of the topic. */
        topic_id: string;
        /** Name of the topic. */
        topic_name?: string;
        /** Last updated time of the subscription. */
        updated_at: string;
    }
    /** SubscriptionUpdateAttributes. */
    interface SubscriptionUpdateAttributes {
    }
    /** Topic object. */
    interface Topic {
        /** Autogenerated topic ID. */
        id: string;
        /** Description of the topic. */
        description: string;
        /** Name of the topic. */
        name: string;
        /** Last time the topic was updated. */
        updated_at: string;
        /** Number of sources. */
        source_count: number;
        /** List of sources. */
        sources: TopicSourcesItem[];
        /** Number of subscriptions. */
        subscription_count: number;
        /** List of subscriptions. */
        subscriptions: SubscriptionListItem[];
    }
    /** Topic list object. */
    interface TopicList {
        /** Number of topics. */
        total_count: number;
        /** Current offset. */
        offset: number;
        /** limit to show subscriptions. */
        limit: number;
        /** List of topics. */
        topics: TopicsListItem[];
    }
    /** Topic object. */
    interface TopicResponse {
        /** Autogenerated topic ID. */
        id: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description: string;
        /** Last time the topic was updated. */
        created_at: string;
    }
    /** TopicSourcesItem. */
    interface TopicSourcesItem {
        /** ID of the source. */
        id: string;
        /** Name of the source. */
        name: string;
        /** List of rules. */
        rules: RulesGet[];
    }
    /** TopicUpdateSourcesItem. */
    interface TopicUpdateSourcesItem {
        /** ID of the source. */
        id: string;
        /** List of rules. */
        rules: Rules[];
    }
    /** Topic list item object. */
    interface TopicsListItem {
        /** Autogenerated topic ID. */
        id: string;
        /** Name of the topic. */
        name: string;
        /** Description of the topic. */
        description: string;
        /** Number of sources. */
        source_count: number;
        /** List of source names. */
        sources_names: string[];
        /** Number of subscriptions. */
        subscription_count: number;
    }
    /** Payload describing a webhook destination configuration. */
    interface DestinationConfigParamsWebhookDestinationConfig extends DestinationConfigParams {
        /** URL of webhook. */
        url: string;
        /** HTTP method of webhook. */
        verb: string;
        /** Custom headers (Key-Value pair) for webhook call. */
        custom_headers?: JsonObject;
        /** List of sensitive headers from custom headers. */
        sensitive_headers?: string[];
    }
    /** The attributes for an email notification. */
    interface SubscriptionAttributesEmailAttributesResponse extends SubscriptionAttributes {
        /** The email id string. */
        to: string[];
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to: string;
        /** The recipient selection method. */
        recipient_selection: string;
    }
    /** SMS attributes object. */
    interface SubscriptionAttributesSMSAttributesResponse extends SubscriptionAttributes {
        /** The phone number to send the SMS to. */
        to: string[];
        /** The recipient selection method. */
        recipient_selection: string;
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionAttributesWebhookAttributesResponse extends SubscriptionAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
        /** Decision for Notification Payload to be added. */
        add_notification_payload: boolean;
    }
    /** The attributes for an email notification. */
    interface SubscriptionCreateAttributesEmailAttributes extends SubscriptionCreateAttributes {
        /** The email id string. */
        to: string[];
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to?: string;
    }
    /** SMS attributes object. */
    interface SubscriptionCreateAttributesSMSAttributes extends SubscriptionCreateAttributes {
        /** The phone number to send the SMS to. */
        to: string[];
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionCreateAttributesWebhookAttributes extends SubscriptionCreateAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
    }
    /** The attributes for an email notification. */
    interface SubscriptionUpdateAttributesEmailAttributes extends SubscriptionUpdateAttributes {
        /** The email id string. */
        to: string[];
        /** Whether to add the notification payload to the email. */
        add_notification_payload: boolean;
        /** The email address to reply to. */
        reply_to?: string;
    }
    /** SMS attributes object. */
    interface SubscriptionUpdateAttributesSMSAttributes extends SubscriptionUpdateAttributes {
        /** The phone number to send the SMS to. */
        to: string[];
    }
    /** The attributes for a webhook notification. */
    interface SubscriptionUpdateAttributesWebhookAttributes extends SubscriptionUpdateAttributes {
        /** Signing webhook attributes. */
        signing_enabled: boolean;
    }
}
export = EventNotificationsV1;
